@@ -4,9 +4,10 @@ use strict;
 use warnings;
 use utf8;
 use POSIX qw/floor/;
+use Carp qw/croak/;
 
 # ABSTRACT: Numbers to words in russian (without currency, but with specified gender)
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 # AUTHORITY
 
 use Exporter qw/import/;
@@ -97,6 +98,7 @@ sub num2rus_cardinal {
     my ( $number, $gender ) = @_;
 
     $gender ||= 'MASCULINE';    # masculine by default
+    croak "Wrong gender: $gender, should be MASCULINE|FEMININE|NEUTER" unless $gender =~ /masculine|feminine|neuter/i;
     $gender = uc $gender;
 
     return _get_string( 0, 0, 0 ) unless $number;    # no extra calculations for zero
@@ -197,7 +199,7 @@ Lingua::RU::Num2Word - Numbers to words in russian (without currency, but with s
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -210,7 +212,9 @@ Translates number to text converter for russian, using the specified gender. Ret
 Main code was taken from L<Lingua::RUS::Number>.
 
 $gender
+
     Can be
+
         FEMININE
         MASCULINE
         NEUTER
